"""Assonant data classes types.

This submodule defines Enumations classes used to standardize type options existing in some data classes.
"""
from .scope_type import ScopeType
from .transformation_type import TransformationType

__all__ = [
    "ScopeType",
    "TransformationType",
]
