"""Exceptions triggered to warn about internal errors in Assonant NeXus module."""


class NeXusObjectFactoryError(Exception):
    """Custom Exception to warn when any error occurs inside NeXusObjectFactory."""

    pass
