"""Assonant DataHandler abstract class."""
from ..assonant_data_class import AssonantDataClass


# TODO: Make this class abstract
class DataHandler(AssonantDataClass):
    """Abstract class that creates the base common requirements to define an Assonant DataHandler."""
