"""Assonant Monochromator Crystal subcomponent data class."""
from .subcomponent import Subcomponent


class MonochromatorCrystal(Subcomponent):
    """Data class to handle all data required to define a crystal from a Monochromator."""
