"""Exceptions triggered to warn about internal errors in Assonant File Writer module."""


class AssonantFileWriterError(Exception):
    """Assonant Data Sender Error.

    Custom Exception to warn when any error occurs inside AssonantFileWriter
    """

    pass
