"""Assonant Detector Submodule subcomponent data class."""
from .subcomponent import Subcomponent


class DetectorModule(Subcomponent):
    """Data class to handle all data required to define a Module from a Detector."""
