"""Assonant Detector ROI subcomponent data class."""
from .subcomponent import Subcomponent


class DetectorROI(Subcomponent):
    """Data class to handle all data required to define a Region of Interest(ROI) taken from a Detector."""
