"""Assonant Monochromator Velocity Selector subcomponent data class."""
from .subcomponent import Subcomponent


class MonochromatorVelocitySelector(Subcomponent):
    """Data class to handle all data required to define a Velocity Selector from a Monochromator."""
